@@ -41,7 +41,9 @@ logger_base.setLevel(logging.getLevelName(getenv("LOG_LEVEL", "INFO")))
 logger_base.addHandler(logging.StreamHandler())
 logger = logging.LoggerAdapter(logging.getLogger("default"))
 
-app = typer.Typer(help="build, tag, and push images")
+app = typer.Typer(
+    help="build, tag, and push images\n\nNOTE: set LOG_LEVEL environment variable to adjust logging (e.g. $ LOG_LEVEL=DEBUG ib build -i minor)"
+)
 app.add_typer(ibuilder.history.app, name="history")
 app.add_typer(ibuilder.images.app, name="images")
 
@@ -153,7 +155,7 @@ def build(
                 logger.debug("- build the image...")
                 _image_build = image_build(client=client, prj=_prj, app=APP)
                 if _image_build:
-                    logger.debug("- build succeeded with: {_image_build}")
+                    logger.debug(f"- build succeeded with: {_image_build}")
                     console.log("✓ build complete")
                     task_status.append(TaskStatus.build_ok)
                 else:
