@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #  SPDX-License-Identifier: GPL-3.0-only
-#  Copyright 2020 drad <drader@adercon.com>
+#  Copyright 2022 drad <sa@adercon.com>
 
 from enum import Enum
 from typing import List
@@ -36,10 +36,16 @@ class TaskStatus(str, Enum):
     repush_fail = "repush fail"
     source_tag_ok = "source tag ok"
     source_tag_fail = "source tag failure"
+    sign_ok = "sign ok"
+    sign_fail = "sign failure"
+    sign_latest_ok = "sign latest ok"
+    sign_latest_fail = "sign latest failure"
 
 
 class History(BaseModel):
-    """Base History."""
+    """
+    History
+    """
 
     created: str = None
     runtime: float = None
@@ -47,10 +53,18 @@ class History(BaseModel):
     task_status: List[TaskStatus] = []
     calling_params: str = None
     run_params: dict = None
+    build_logs: str = None
+    tag_source_logs: str = None
+    tag_source_push_logs: str = None
+    image_push_logs: str = None
+    image_push_latest_logs: str = None
+    sign_logs: str = None
     last: bool = False
 
 
 class HistoryOnDB(History):
-    """Extended History ."""
+    """
+    Extended History
+    """
 
     doc_id: str = None
